/******************************************************************************
 * JBoss, a division of Red Hat                                               *
 * Copyright 2010, Red Hat Middleware, LLC, and individual                    *
 * contributors as indicated by the @authors tag. See the                     *
 * copyright.txt in the distribution for a full listing of                    *
 * individual contributors.                                                   *
 *                                                                            *
 * This is free software; you can redistribute it and/or modify it            *
 * under the terms of the GNU Lesser General Public License as                *
 * published by the Free Software Foundation; either version 2.1 of           *
 * the License, or (at your option) any later version.                        *
 *                                                                            *
 * This software is distributed in the hope that it will be useful,           *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of             *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU           *
 * Lesser General Public License for more details.                            *
 *                                                                            *
 * You should have received a copy of the GNU Lesser General Public           *
 * License along with this software; if not, write to the Free                *
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA         *
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.                   *
 ******************************************************************************/
package org.gatein.gadget.client;

import java.util.Date;

import com.google.gwt.core.client.GWT;
import com.google.gwt.gadgets.client.Gadget;
import com.google.gwt.gadgets.client.UserPreferences;
import com.google.gwt.gadgets.client.Gadget.ModulePrefs;
import com.google.gwt.user.client.rpc.AsyncCallback;
import com.google.gwt.user.client.ui.Label;
import com.google.gwt.user.client.ui.RootPanel;

/**
 * Creates a gadget that will show a welcome message with the users first name
 * and display that last time the user logged into the system.
 */
@ModulePrefs(title = "GTN Gwt Gadget", author = "mwringe", author_email = "mwringe@redhat.com")
public class Application extends Gadget<UserPreferences>
{
   // asycn services to get requests from the server through ajax.
   private final UserServiceAsync userService = GWT.create(UserService.class);

   // gui elements
   private Label welcomeLabel;

   private Label timeLabel;

   @Override
   protected void init(UserPreferences preferences)
   {
      welcomeLabel = new Label();
      timeLabel = new Label();
      RootPanel.get().add(welcomeLabel);
      RootPanel.get().add(timeLabel);
      getUserInfo();
   }

   protected void getUserInfo()
   {
      // get the users name and display it in a welcome message
      userService.getFirstName(new AsyncCallback<String>()
      {

         public void onFailure(Throwable throwable)
         {
            welcomeLabel.setText("An error occured when trying to get the username" + throwable.getMessage() + " : "
                  + throwable.getCause());
            throwable.printStackTrace();
         }

         public void onSuccess(String username)
         {
            if (username != null)
            {
               welcomeLabel.setText("Welcome " + username);
            }
            else
            {
               welcomeLabel.setText("No Logged in User");
            }
         }

      });

      // get the last time the user logged into the system and display it in a message
      userService.getLastLoggedIn(new AsyncCallback<Date>()
      {

         public void onFailure(Throwable throwable)
         {
            timeLabel.setText("An error has occured trying to get the previous login time." + throwable.getMessage()
                  + " : " + throwable.getCause());
            throwable.printStackTrace();
         }

         public void onSuccess(Date timeLastLogin)
         {
            if (timeLastLogin != null)
            {
               timeLabel.setVisible(true);
               timeLabel.setText("Last login: " + timeLastLogin);
            }
            else
            {
               timeLabel.setVisible(false);
            }
         }
      });
   }
}
