/******************************************************************************
 * JBoss, a division of Red Hat                                               *
 * Copyright 2010, Red Hat Middleware, LLC, and individual                    *
 * contributors as indicated by the @authors tag. See the                     *
 * copyright.txt in the distribution for a full listing of                    *
 * individual contributors.                                                   *
 *                                                                            *
 * This is free software; you can redistribute it and/or modify it            *
 * under the terms of the GNU Lesser General Public License as                *
 * published by the Free Software Foundation; either version 2.1 of           *
 * the License, or (at your option) any later version.                        *
 *                                                                            *
 * This software is distributed in the hope that it will be useful,           *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of             *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU           *
 * Lesser General Public License for more details.                            *
 *                                                                            *
 * You should have received a copy of the GNU Lesser General Public           *
 * License along with this software; if not, write to the Free                *
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA         *
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.                   *
 ******************************************************************************/
package org.gatein.gadget.server;

import java.util.Date;

import org.exoplatform.container.PortalContainer;
import org.exoplatform.services.organization.OrganizationService;
import org.exoplatform.services.organization.User;
import org.gatein.gadget.client.UserService;

import com.google.gwt.user.server.rpc.RemoteServiceServlet;

/**
 * @author <a href="mailto:mwringe@redhat.com">Matt Wringe</a>
 * @version $Revision$
 */
public class UserServiceImpl extends RemoteServiceServlet implements UserService
{

   public String getFirstName() throws Exception
   {
      User exoUser = getUser();
      if (exoUser != null)
      {
         return exoUser.getFirstName();
      }
      else
      {
         return null;
      }
   }
   
   public Date getLastLoggedIn() throws Exception
   {
      User exoUser = getUser();
      if (exoUser != null)
      {
         return exoUser.getLastLoginTime();
      }
      else
      {
         return null;
      }
   }
   
   /**
    * Retrieve the remoteuser name from the request
    * 
    * @return the remoteuser name
    */
   private String getRemoteUser()
   {
      return this.perThreadRequest.get().getRemoteUser();
   }
   
   /**
    * Retrieve the portal container.
    * 
    * @return The portal container object
    */
   private PortalContainer getPortalContainer()
   {
      return PortalContainer.getInstance();
   }
   
   /**
    * Retrieve the OrganizationService the PortalContainer is using.
    * 
    * @param portalContainer The portal container to use
    * @return The organization service
    */
   private OrganizationService getOrganizationService(PortalContainer portalContainer)
   {
      if (portalContainer != null)
      {
         return (OrganizationService)portalContainer.getComponentInstanceOfType(OrganizationService.class);
      }
      else
      {
         return null;
      }
   }
   
   /**
    * Retrieve the User object from the portal server.
    * 
    * @return THe User object
    * @throws Exception
    */
   private User getUser() throws Exception
   {
      String remoteUser = getRemoteUser();
      OrganizationService orgService = getOrganizationService(getPortalContainer());
      if (orgService != null && remoteUser != null)
      {
         return orgService.getUserHandler().findUserByName(remoteUser);
      }
      else
      {
         return null;
      }
   }

}

